#This script produces all the jpegs for Figure A8.
rm(list = ls(all.names = TRUE))

#Step 1. Loading libraries
install.packages("ggplot2")

library("ggplot2")

#Step 2. Setting directory
#Mac or Windows
setwd("/Users/bgpopescu/Dropbox/Education Project/")
setwd("C:/Users/bogdanp/Dropbox/Education project/")
setwd("C:/Users/Popescu/Dropbox/Education project/")


#Step 3 In case it does not exist already, manually create a folder called "figures" in the Paper folder
#so that you can save the output from this script.

#Step 4. Reading Data
data<-read.csv(file="./Data/data_final.csv", header=TRUE, sep=",")

#Step 5. Selecting the data for the area of interest
data_final<-subset(data, agrozone==3)

#Step 6. Creating distances for RD analysis
data_final$dist1 <- as.numeric( with (data_final,ifelse(data_final$treat==1, 1, -1)))
data_final$dist2 <-data_final$dist1*data_final$core13_dist

#Step 7. Creating the Border Fixed Effects (BFEs)
data_final$bfe1 <- ifelse(data_final$core13_id == 1, 1,0)
data_final$bfe2 <- ifelse(data_final$core13_id == 2, 1,0)
data_final$bfe3 <- ifelse(data_final$core13_id == 3, 1,0)

#Step 8. Creating the placebo sample
placebo <-data_final[which(data_final$dist2>-100 & data_final$dist2<100),]

#Step 9. Define range of locations for placebo border
sequence=seq(from=-90, to=90, by=1)


#######################################################################
#PLACEBO Figure A8a: fgt0_onlydistbfe - Poverty Headcount Ratio (2009)#
#######################################################################

#Create empty variables
p.value=rep(NA, length(sequence))
estimate=rep(NA, length(sequence))
confint1=rep(NA, length(sequence))
confint2=rep(NA, length(sequence))
#Loop over potential placebo locations of border
for(i in 1:length(sequence)){
  placebo$dist3=placebo$dist2+sequence[i]
  placebo$treat2=ifelse(placebo$dist3 > 0, placebo$treat <- 1, placebo$treat <- 0)
  model1<-lm(fgt0 ~ treat2 + core13_dist + bfe1 + bfe2 + bfe3, data = placebo)
  confint1[i]=confint(model1)[2,1]
  confint2[i]=confint(model1)[2,2]
  estimate[i]=coef(model1)[2]
}

placebo_data <- data.frame(sequence, estimate, confint1, confint2)

fgt0_placebo_onlydistbfe<-ggplot(data=placebo_data, aes(sequence, estimate))+
  geom_point(size=1.3)+
  geom_point(data = placebo_data[placebo_data$confint1 > 0,], color= "red", size = 2)+ 
  geom_errorbar(aes(ymin=confint1, ymax=confint2), size=0.2, width = 0)+
  geom_errorbar(data = placebo_data[placebo_data$confint1 > 0,],
                aes(ymin=confint1, ymax=confint2), size=0.2, width = 0, color= "red")+
  geom_hline(yintercept = 0)+
  theme_bw()+
  scale_x_continuous(name="Placebo border distance from actual border (km)", breaks = seq(-90, 90, 20)) +
  scale_y_continuous(name="Estimated effect")+
  ggtitle("Poverty Headcount Ratio (2009)") +
  theme(plot.title = element_text(hjust = 0.5),
        axis.text.x = element_text(size=14),
        axis.text.y = element_text(size=14),
        axis.title=element_text(size=14))
fgt0_placebo_onlydistbfe

ggsave(fgt0_placebo_onlydistbfe, 
       file="./Paper/figures/Figure A8a.jpg", 
       height=10, width=20, 
       units = "cm", dpi=300)


#################################################################
#PLACEBO Figure A8b: fgt1_onlydistbfe - Poverty Gap Index (2009)#
#################################################################

#Create empty variables
p.value=rep(NA, length(sequence))
estimate=rep(NA, length(sequence))
confint1=rep(NA, length(sequence))
confint2=rep(NA, length(sequence))
#Loop over potential placebo locations of border
for(i in 1:length(sequence)){
  placebo$dist3=placebo$dist2+sequence[i]
  placebo$treat2=ifelse(placebo$dist3 > 0, placebo$treat <- 1, placebo$treat <- 0)
  model1<-lm(fgt1 ~ treat2 + core13_dist + bfe1 + bfe2 + bfe3, data = placebo)
  confint1[i]=confint(model1)[2,1]
  confint2[i]=confint(model1)[2,2]
  estimate[i]=coef(model1)[2]
}

placebo_data <- data.frame(sequence, estimate, confint1, confint2)

fgt1_placebo_onlydistbfe<-ggplot(data=placebo_data, aes(sequence, estimate))+
  geom_point(size=1.3)+
  geom_point(data = placebo_data[placebo_data$confint1 > 0,], color= "red", size = 2)+ 
  geom_errorbar(aes(ymin=confint1, ymax=confint2), size=0.2, width = 0)+
  geom_errorbar(data = placebo_data[placebo_data$confint1 > 0,],
                aes(ymin=confint1, ymax=confint2), size=0.2, width = 0, color= "red")+
  geom_hline(yintercept = 0)+
  theme_bw()+
  scale_x_continuous(name="Placebo border distance from actual border (km)", breaks = seq(-90, 90, 20)) +
  scale_y_continuous(name="Estimated effect")+
  ggtitle("Poverty Gap Index (2009)") +
  theme(plot.title = element_text(hjust = 0.5),
        axis.text.x = element_text(size=14),
        axis.text.y = element_text(size=14),
        axis.title=element_text(size=14))

ggsave(fgt1_placebo_onlydistbfe, 
       file="./Paper/figures/Figure A8b.jpg", 
       height=10, width=20, 
       units = "cm", dpi=300)



################################################################
#PLACEBO Figure A8c: fgt2_onlydistbfe - Poverty Severity (2009)#
################################################################

#Create empty variables
p.value=rep(NA, length(sequence))
estimate=rep(NA, length(sequence))
confint1=rep(NA, length(sequence))
confint2=rep(NA, length(sequence))
#Loop over potential placebo locations of border
for(i in 1:length(sequence)){
  placebo$dist3=placebo$dist2+sequence[i]
  placebo$treat2=ifelse(placebo$dist3 > 0, placebo$treat <- 1, placebo$treat <- 0)
  model1<-lm(fgt2 ~ treat2 + core13_dist + bfe1 + bfe2 + bfe3, data = placebo)
  confint1[i]=confint(model1)[2,1]
  confint2[i]=confint(model1)[2,2]
  estimate[i]=coef(model1)[2]
}

placebo_data <- data.frame(sequence, estimate, confint1, confint2)

fgt2_placebo_onlydistbfe<-ggplot(data=placebo_data, aes(sequence, estimate))+
  geom_point(size=1.3)+
  geom_point(data = placebo_data[placebo_data$confint1 > 0,], color= "red", size = 2)+ 
  geom_errorbar(aes(ymin=confint1, ymax=confint2), size=0.2, width = 0)+
  geom_errorbar(data = placebo_data[placebo_data$confint1 > 0,],
                aes(ymin=confint1, ymax=confint2), size=0.2, width = 0, color= "red")+
  geom_hline(yintercept = 0)+
  theme_bw()+
  scale_x_continuous(name="Placebo border distance from actual border (km)", breaks = seq(-90, 90, 20)) +
  scale_y_continuous(name="Estimated effect")+
  ggtitle("Poverty Severity (2009)") +
  theme(plot.title = element_text(hjust = 0.5),
        axis.text.x = element_text(size=14),
        axis.text.y = element_text(size=14),
        axis.title=element_text(size=14))

ggsave(fgt2_placebo_onlydistbfe, 
       file="./Paper/figures/Figure A8c.jpg", 
       height=10, width=20, 
       units = "cm", dpi=300)


############################################################################
#PLACEBO Figure A8d: pobreza13_onlydistbfe - Poverty Headcount Ratio (2013)#
############################################################################

#Create empty variables
p.value=rep(NA, length(sequence))
estimate=rep(NA, length(sequence))
confint1=rep(NA, length(sequence))
confint2=rep(NA, length(sequence))
#Loop over potential placebo locations of border
for(i in 1:length(sequence)){
  placebo$dist3=placebo$dist2+sequence[i]
  placebo$treat2=ifelse(placebo$dist3 > 0, placebo$treat <- 1, placebo$treat <- 0)
  model1<-lm(pobreza13 ~ treat2 + core13_dist + bfe1 + bfe2 + bfe3, data = placebo)
  confint1[i]=confint(model1)[2,1]
  confint2[i]=confint(model1)[2,2]
  estimate[i]=coef(model1)[2]
}

placebo_data <- data.frame(sequence, estimate, confint1, confint2)

pobreza13_placebo_onlydistbfe<-ggplot(data=placebo_data, aes(sequence, estimate))+
  geom_point(size=1.3)+
  geom_point(data = placebo_data[placebo_data$confint1 > 0,], color= "red", size = 2)+ 
  geom_errorbar(aes(ymin=confint1, ymax=confint2), size=0.2, width = 0)+
  geom_errorbar(data = placebo_data[placebo_data$confint1 > 0,],
                aes(ymin=confint1, ymax=confint2), size=0.2, width = 0, color= "red")+
  geom_hline(yintercept = 0)+
  theme_bw()+
  scale_x_continuous(name="Placebo border distance from actual border (km)", breaks = seq(-90, 90, 20)) +
  scale_y_continuous(name="Estimated effect")+
  ggtitle("Poverty Headcount Ratio (2013)") +
  theme(plot.title = element_text(hjust = 0.5),
        axis.text.x = element_text(size=14),
        axis.text.y = element_text(size=14),
        axis.title=element_text(size=14))

ggsave(pobreza13_placebo_onlydistbfe, 
       file="./Paper/figures/Figure A8d.jpg", 
       height=10, width=20, 
       units = "cm", dpi=300)

