#This script produces the jpeg for Figure 7.
rm(list = ls(all.names = TRUE))

#Step 1. Loading libraries
install.packages("ggplot2")
install.packages("glue")
install.packages("gridExtra")
install.packages("grid")
install.packages("cowplot")
install.packages("scales")
install.packages("lemon")
install.packages("dplyr")


library("ggplot2")
library("glue")
library('gridExtra')
library('grid')
library('cowplot')
library('scales')
library('lemon')
library('dplyr')

#Step 2. Setting directory
#Mac or Windows
setwd("/Users/bgpopescu/Dropbox/Education Project/")
setwd("C:/Users/bogdanp/Dropbox/Education project/")
setwd("C:/Users/Popescu/Dropbox/Education project/")


#Step 3 In case it does not exist already, manually create a folder called "figures" in the Paper folder
#so that you can save the output from this script.

#Step 4. Reading Data
data<-read.csv(file="./Data/data_final.csv", header=TRUE, sep=",")

#Step 5. Selecting the data for the area of interest
data_final<-subset(data, agrozone==3)

#Step 6. Creating distances for RD analysis
data_final$dist1 <- as.numeric( with (data_final,ifelse(data_final$treat==1, 1, -1)))
data_final$dist2 <-data_final$dist1*data_final$core13_dist

#Step 7. Creating the Border Fixed Effects (BFEs)
data_final$bfe1 <- ifelse(data_final$core13_id == 1, 1,0)
data_final$bfe2 <- ifelse(data_final$core13_id == 2, 1,0)
data_final$bfe3 <- ifelse(data_final$core13_id == 3, 1,0)

#Step 8. Subset the sample to less than 85km and create "treatment" and "control" dummies
data2<-data_final%>%
  filter(abs(dist2)<85)%>%
  mutate(left=ifelse(dist2<0, "Control", "Treatment"))


##########
#RD GRAPH#
##########


mEE_DR_13_1980_pcSupM_adj_rd<-ggplot(data=data2, aes(dist2, mEE_DR_13_1980_pcSupM_adj, color=left, label=name))+
  geom_smooth(method="loess")+
  geom_point(size=0.5)+
  scale_x_continuous(name="Bandwidth (km)", breaks = seq(-85, 85, 20)) +
  scale_y_continuous(name="Pct. of Land Reformed", limit=c(0,100),oob=squish)+
  geom_vline(xintercept = 0)+
  theme(plot.title = element_text(hjust = 0.5))+
  ggtitle("Loess")+
  geom_text(aes(label = name),
            size = 2, check_overlap = TRUE, position = position_nudge(y = 2))+
  theme_bw()+
  scale_color_manual("", values=c("Control"="black", "Treatment"="red"), guide='legend')+
  theme(plot.title = element_text(hjust = 0.5, size=15),
        axis.text=element_text(size=12),
        axis.title.x = element_text(size=15),
        axis.title.y = element_text(size=15))+
  theme(legend.position=c(0.85,0.85),
        legend.box.background = element_rect(fill='white'),
        legend.background = element_blank(),
        legend.text=element_text(size=10))

mEE_DR_13_1980_pcSupM_adj_rd<-reposition_legend(mEE_DR_13_1980_pcSupM_adj_rd, 'bottom right')


mEE_DR_13_1980_pcSupM_adj_LM_rd<-ggplot(data=data2, aes(dist2, mEE_DR_13_1980_pcSupM_adj, color=left, label=name))+
  geom_smooth(method="lm")+
  geom_point(size=0.5)+
  scale_x_continuous(name="Bandwidth (km)", breaks = seq(-85, 85, 20)) +
  scale_y_continuous(name="Pct. of Land Reformed", breaks = seq(0, 100, 25)) +
  geom_vline(xintercept = 0)+
  theme(plot.title = element_text(hjust = 0.5))+
  ggtitle("Linear")+
  geom_text(aes(label = name),
            size = 2, check_overlap = TRUE, position = position_nudge(y = 2))+
  theme_bw()+
  scale_color_manual("", values=c("Control"="black", "Treatment"="red"), guide='legend')+
  theme(plot.title = element_text(hjust = 0.5, size=15),
        axis.text=element_text(size=12),
        axis.title.x = element_text(size=15),
        axis.title.y = element_text(size=15))+
  theme(legend.position=c(0.85,0.85),
        legend.box.background = element_rect(fill='white'),
        legend.background = element_blank(),
        legend.text=element_text(size=10))

mEE_DR_13_1980_pcSupM_adj_LM_rd<-reposition_legend(mEE_DR_13_1980_pcSupM_adj_LM_rd, 'bottom right')

grid<-plot_grid(mEE_DR_13_1980_pcSupM_adj_LM_rd, mEE_DR_13_1980_pcSupM_adj_rd, nrow=1,ncol=2)

shortcut = glue("./Paper/figures")
setwd(shortcut)

ggsave(grid, file ="Figure 7.jpg", 
       height = 10, width = 50, 
       units = "cm", dpi = 300)

