#This script produces the maps in Figure 1
rm(list = ls(all.names = TRUE))

#Step 1. Loading libraries
#NOTE: There might be some errors with the gpclib permissions. If there are errors, 
#R should be shut down and restarted. 
install.packages("ggplot2")
install.packages("rgdal")
install.packages("RColorBrewer")
install.packages("lemon")
install.packages("dplyr")
install.packages("maptools")
install.packages('rgeos', type='source')
install.packages("gpclib", type="source")


library("ggplot2")
library('rgdal')
library('RColorBrewer')
library('lemon')
library("dplyr")
library("maptools")
library("rgeos")
library("gpclib")


#Step 2. Setting directory
#Mac or Windows
setwd("/Users/bgpopescu/Dropbox/Education Project/")
setwd("C:/Users/bogdanp/Dropbox/Education project/")
setwd("C:/Users/Popescu/Dropbox/Education project/")


#Step 3. In case it does not exist already, manually create a folder called "figures" in the Paper folder
#so that you can save the output from this script.

#Step 4. Reading shape files from geodatabase
#Department polygons
departments <- readOGR(dsn="./Data/map_data.gdb",
                     layer="departments", use_iconv = TRUE, encoding = "UTF-8")
departments_centroids.df <- as.data.frame(coordinates(departments))
#Defining more sensible column names
names(departments_centroids.df) <- c("Longitude", "Latitude")
departments<- fortify(departments, region="Department")
departments$id<-factor(departments$id)


#Agrozone polygons
agrozones <- readOGR(dsn="./Data/map_data.gdb",
                     layer="agrozones", use_iconv = TRUE, encoding = "UTF-8")
agrozones_centroids.df <- as.data.frame(coordinates(agrozones))
#Defining more sensible column names
names(agrozones_centroids.df) <- c("Longitude", "Latitude")
agrozones<- fortify(agrozones, region="Agrozone")
agrozones$id<-factor(agrozones$id)


#Step 5. Create the left panel in Fgure 1: Agrarian Zones and Departments in Peru
p <- ggplot() +
  geom_polygon(data = agrozones, aes(x = long, 
                                    y = lat, 
                                     group = group),
               color = "black", size = 0.1, fill=NA) +
  geom_text(aes(label = unique(agrozones$id), x = agrozones_centroids.df$Longitude, 
                y = agrozones_centroids.df$Latitude))+
  theme_bw()+
  labs(x = "Longitude", y="Latitude")+
  ggtitle("Agrarian Reform Zones")+
  theme(plot.title = element_text(hjust = 0.5),
        axis.text.x = element_text(size=14),
        axis.text.y = element_text(size=14),
        axis.title=element_text(size=14),
        legend.position = c(1, 0),
        legend.box.background = element_rect(fill='white'),
        legend.background = element_blank(),
        legend.text=element_text(size=12))


ggsave(p, 
       file="./Paper/figures/Figure 1a.jpg", 
       height=30, width=20, 
       units = "cm", dpi=300)


#Step 6. Create the right panel in Fgure 1: Agrarian Zones and Departments in Peru
q <- ggplot() +
  geom_polygon(data = departments, aes(x = long, 
                                     y = lat, 
                                     group = group),
               color = "black", size = 0.1, fill=NA) +
  
  geom_text(aes(label = unique(departments$id), x = departments_centroids.df$Longitude, 
                y = departments_centroids.df$Latitude))+
  theme_bw()+
  labs(x = "Longitude", y="Latitude")+
  ggtitle("Departments")+
  theme(plot.title = element_text(hjust = 0.5))+
  theme(plot.title = element_text(hjust = 0.5),
        axis.text.x = element_text(size=14),
        axis.text.y = element_text(size=14),
        axis.title=element_text(size=14),
        legend.position = c(1, 0),
        legend.box.background = element_rect(fill='white'),
        legend.background = element_blank(),
        legend.text=element_text(size=12))

ggsave(q, 
       file="./Paper/figures/Figure 1b.jpg", 
       height=30, width=20, 
       units = "cm", dpi=300)

