#This script produces the maps in Figure 3
rm(list = ls())

#Step 1. Loading libraries
#NOTE: There might be some errors with the gpclib permissions. If there are errors, 
#R should be shut down and restarted. 
install.packages("ggplot2")
install.packages("dplyr")
install.packages("RColorBrewer")
install.packages("lemon")
install.packages("maptools")
install.packages('rgeos', type='source')
install.packages('rgdal', type='source')
install.packages("gpclib", type="source")


library("ggplot2")
library("dplyr")
library('rgdal')
library('RColorBrewer')
library('lemon')
library('maptools')
library("rgeos")
library("rgdal")
library("gpclib")



#Step 2. Setting directory
#Mac or Windows
setwd("/Users/bgpopescu/Dropbox/Education Project/")
setwd("C:/Users/bogdanp/Dropbox/Education project/")
setwd("C:/Users/Popescu/Dropbox/Education project/")


#Step 3. In case it does not exist already, manually create a folder called "figures" in the Paper folder
#so that you can save the output from this script.

#Step 4. Reading Data
data<-read.csv(file="./Data/data_final.csv", header=TRUE, sep=",")

#Step 5. Subseting the data to contain only the variables of interest
peru_1975<-subset(data, select=c(codeconc, mEE_DR_123_1980_pcSupM_adj))

#Step 6. Reading shape files from geodatabase
#Core-Periphery Border Line
core_periph_brd <- readOGR(dsn="./Data/map_data.gdb",
                     layer="core_periph_brd", use_iconv = TRUE, encoding = "UTF-8")
core_periph_brd<- fortify(core_periph_brd)
core_periph_brd$id<-factor(core_periph_brd$id)

#Agrozone polygons
agrozones <- readOGR(dsn="./Data/map_data.gdb",
                    layer="agrozones", use_iconv = TRUE, encoding = "UTF-8")
agrozones@data
agrozones<- fortify(agrozones, region="Agrozone")
agrozones$id<-factor(agrozones$id)

#Agrozone 3 polygon
agrozone3 <- readOGR(dsn="./Data/map_data.gdb",
                     layer="agrozone3", use_iconv = TRUE, encoding = "UTF-8")
agrozone3<- fortify(agrozone3)
agrozone3$id<-factor(agrozone3$id)

#1975 District polygons
districts_1975 <- readOGR(dsn="./Data/map_data.gdb",
                       layer="districts_1975", use_iconv = TRUE, encoding = "UTF-8")
districts_1975<- fortify(districts_1975, region="codeconc")

#Agrozone Core Polygon
inside_zone3_core <- readOGR(dsn="./Data/map_data.gdb",
                          layer="inside_zone3_core", use_iconv = TRUE, encoding = "UTF-8")
inside_zone3_core<- fortify(inside_zone3_core)
inside_zone3_core$id<-factor(inside_zone3_core$id)

#Step 7. Merging original data to the 1975 district polygons
districts_1975$codeconc<-districts_1975$id
peru_1975$codeconc<-as.character(peru_1975$codeconc)
mapa.df<-left_join(districts_1975, peru_1975, by = c("codeconc"="codeconc"))
names(mapa.df)

#Step 8. Creating legend classes
no_classes <- 7
labels <- c()

#Step 9. Manually defining categories
obj <- c(0, 0.001, 0.1, 0.2, 0.3, 0.4, 0.5, 0.75, 1)

#Step 10. Defining custom labels
labels <- c()
for(idx in 1:length(obj)){
  labels <- c(labels, paste0(round(obj[idx], 4), 
                             "-", 
                             round(obj[idx + 1], 4)))
}

#Step 11. Removing the last label to avoid something like "66.62 - NA"
labels <- labels[1:length(labels)-1]

#Step 12. Creating a new variable on the dataset with the obj
mapa.df$mEE_DR_13_1980_pcSupM_adj_B <- cut(mapa.df$mEE_DR_123_1980_pcSupM_adj, 
                                 breaks = obj, 
                                 labels = labels, 
                                 include.lowest = T,
                                 exclude=NULL)

#Step 13. Defining 8 shades of Grey
my.cols <- brewer.pal(8, "Greys")


#This is to obtain the left panel in Figure 3: Land Reform by District in Peru
#The map shows land reform by district

p <- ggplot() +
  # municipality polygons
  geom_polygon(data = mapa.df, aes(fill = mEE_DR_13_1980_pcSupM_adj_B, 
                                   x = long, 
                                   y = lat, 
                                   group = group)) +
  # municipality outline
  geom_path(data = mapa.df, aes(x = long, 
                                y = lat, 
                                group = group), 
            color = "gray", size = 0.1) +
  #agrozones outline
  geom_path(data = agrozones, aes(x = long, 
                                y = lat, 
                                group = group), 
            color = "black", size = 0.5) +
  #agrozone3 outline
  geom_path(data = agrozone3, aes(x = long, 
                                  y = lat, 
                                  group = group), 
            color = "black", size = 2) +
  #border-periphery outline
  geom_path(data = core_periph_brd, aes(x=long, y=lat, group = group), colour = "red", size = 1.5)+
  scale_fill_manual("Interval", values = my.cols, guide = "legend") +
  theme_bw()+
  labs(x = "Longitude", y="Latitude")+
  ggtitle("Land Reform Across Peru")+
  theme(plot.title = element_text(hjust = 0.5))+
  theme(legend.position = c(1, 0),
        legend.box.background = element_rect(fill='white'),
        legend.background = element_blank(),
        legend.text=element_text(size=12))

p<-reposition_legend(p, 'bottom left')
p


ggsave(p, 
       file="./Paper/figures/Figure 3a.jpg", 
       height=30, width=20, 
       units = "cm", dpi=300)



#This is to obtain the right panel in Figure 3: Land Reform by District in Peru
#The map shows land reform by district, zoomed on zone 3


p <- ggplot() +
  # municipality polygons
  geom_polygon(data = mapa.df, aes(fill = mEE_DR_13_1980_pcSupM_adj_B, 
                                   x = long, 
                                   y = lat, 
                                   group = group)) +
  # municipality outline
  geom_path(data = mapa.df, aes(x = long, 
                                y = lat, 
                                group = group), 
            color = "gray", size = 0.1) +
  # agrozone outline
  geom_path(data = agrozones, aes(x = long, 
                                  y = lat, 
                                  group = group), 
            color = "black", size = 0.8) +
  # agrozone3 outline
  geom_path(data = agrozone3, aes(x = long, 
                                  y = lat, 
                                  group = group), 
            color = "black", size = 2.2) +
  #border-periphery outline
  geom_path(data = core_periph_brd, aes(x=long, y=lat, group = group), colour = "red", size = 2)+
  coord_cartesian(ylim=c(-10.611, -7.349), xlim=c(-79.465, -76.726))+
  scale_fill_manual("Interval", values = my.cols, guide = "legend") +
  theme_bw()+
  labs(x = "Longitude", y="Latitude")+
  ggtitle("Land Reform in Agrarian Zone 3")+
  theme(plot.title = element_text(hjust = 0.5))+
  theme(legend.position = c(1, 0),
        legend.box.background = element_rect(fill='white'),
        legend.background = element_blank(),
        legend.text=element_text(size=12))+
  scale_colour_grey()

p<-reposition_legend(p, 'bottom left')
p


ggsave(p, 
       file="./Paper/figures/Figure 3b.jpg", 
       height=30, width=20, 
       units = "cm", dpi=300)

