#This script produces all the jpegs for Figure A13 and A14.
rm(list = ls(all.names = TRUE))

#Step 1. Loading libraries
install.packages("ggplot2")
install.packages("glue")
install.packages("MatchIt")
install.packages("dplyr")
install.packages("grid")
install.packages("gridExtra")

library("ggplot2")
library("glue")
library("MatchIt")
library("dplyr")
library("grid")
library("gridExtra")

#Step 2. Setting directory
#Mac or Windows
setwd("/Users/bgpopescu/Dropbox/Education Project/")
setwd("C:/Users/bogdanp/Dropbox/Education project/")
setwd("C:/Users/Popescu/Dropbox/Education project/")


#Step 3. In case it does not exist already, manually create a folder called "figures" in the Paper folder
#so that you can save the output from this script.

#Step 4. Reading Data
data<-read.csv(file="./Data/data_final.csv", header=TRUE, sep=",")

#Step 5. Selecting the data for the area of interest
data_final<-subset(data, agrozone==3)

#Step 6.Selecting only the variables of interest
relevant_data<-select(data_final, c(treat,
                                    x_coord,
                                    y_coord,
                                    core13_dist,
                                    elev,
                                    slope,
                                    pop1972_sup_ha,
                                    icult_land_maj,
                                    total_road_1973,
                                    cotton_intinput_irrigated,
                                    sugarcane_intinput_irrigated,
                                    mEE_DR_13_1980_pcSupM_adj,
                                    fgt0,
                                    fgt1,
                                    fgt2,
                                    pobreza13,
                                    BD_educacion_3_2_matric_1ria_07,
                                    BD_educacion_3_3_matric_2ria_07,
                                    tasa_desnutric_07,
                                    pct_poblac_rural_07,
                                    codeconc))


#Step 7. Removing NAs
trimmed <- relevant_data %>% 
  filter(!is.na(treat) &
           !is.na(x_coord) &
           !is.na(y_coord) &
           !is.na(core13_dist) &
           !is.na(elev) &
           !is.na(slope) &
           !is.na(pop1972_sup_ha) &
           !is.na(icult_land_maj) &
           !is.na(total_road_1973) &
           !is.na(cotton_intinput_irrigated) &
           !is.na(sugarcane_intinput_irrigated) &
           !is.na(mEE_DR_13_1980_pcSupM_adj) &
           !is.na(fgt0) &
           !is.na(fgt1) &
           !is.na(fgt2) &
           !is.na(pobreza13)&
           !is.na(BD_educacion_3_2_matric_1ria_07)&
           !is.na(BD_educacion_3_3_matric_2ria_07)&
           !is.na(tasa_desnutric_07)&
           !is.na(pct_poblac_rural_07))
                              

#Step 8. Matching procedure
m.out1 <- matchit(treat ~ core13_dist+
                  x_coord +
                  y_coord+  
                  elev+
                  slope+
                  pop1972_sup_ha+
                  icult_land_maj+
                  total_road_1973+
                  cotton_intinput_irrigated+
                  sugarcane_intinput_irrigated,
                  data = trimmed, 
                  method = "nearest", 
                  replace=F)	

#Step 9. Creating a new DataFrame
mmdata <- match.data(m.out1)

#Step 10. Creating distances for RD analysis
mmdata$dist1 <- as.numeric( with (mmdata,ifelse(mmdata$treat==1, 1, -1)))
mmdata$dist2 <-mmdata$dist1*mmdata$core13_dist

#################
#Helper Function#
#################

comp_dist <- function(data_sample, y, x) {
  sequence = seq(from = 10, to = 85, by = 1)
  conf.int1 <- rep(NA, length(sequence))
  conf.int2 <- rep(NA, length(sequence))
  estimate <- rep(NA, length(sequence))
  for (i in 1 : length(sequence)){
    #Create empty variables
    bal.data=mmdata[which(mmdata$dist2>-sequence[i] & mmdata$dist2<sequence[i]),]
    t.val=t.test(bal.data[[y]][which(bal.data$treat==1)], 
               bal.data[[y]][which(bal.data$treat==0)])
    conf.int1[i]=t.val$conf.int[1]
    conf.int2[i]=t.val$conf.int[2]
    estimate[i]=t.val$estimate[1]-t.val$estimate[2]
  }
   df <- data.frame(sequence = sequence, estimate = estimate, 
                   conf.int1 = conf.int1, conf.int2 = conf.int2)
   mean_feature <- ggplot(data = df, aes(sequence, estimate)) +
     geom_point(size = 1.3) +
     geom_errorbar(aes(ymin = conf.int1, ymax = conf.int2), size = 0.2, width = 0)+
     geom_hline(yintercept = 0) +
     theme_bw() +
     scale_x_continuous(name = "Bandwidth (km)", limits = c(10, 85)) +
     scale_y_continuous(name = "Estimate") +
     ggtitle(glue("{}")) +
     theme(plot.title = element_text(hjust = 0.5),
           axis.text.x = element_text(size=14),
           axis.text.y = element_text(size=14),
           axis.title=element_text(size=14))+
     annotate(geom = "text", -Inf, Inf, label = c(paste("Treatment:", nrow(mmdata[mmdata$treat==1,]), "\n", 
                                                        "Control:", nrow(mmdata[mmdata$treat==0,]))), hjust = 0, vjust = 1)
   return(mean_feature)
}


create_graphs_per_specifications <- function(regressors, specifications, 
                                             specification_label, data_sample, data_sample_name){
  # Input:
  #   - regressors, a list of dependent variables
  #   - data_sample, the dataset of interest
  #   - data_sample_name, label for the data_sample
  
  # Output:
  #   Creates one grid of pictures in the folder. This function
  #   allows us to vary the regressors.
  
  for (y in regressors) {
    regressor_name  = y[[1]]
    regressor_label = y[[2]]
    figure_no = y[[3]]
    
    print(glue("Using dependent variable {regressor_label}.."))
    graphs <- list()
    temp_graph <- comp_dist(data_sample, regressor_name)
    graphs[[paste(c(regressor_name), collapse = '_')]] <- temp_graph
    
    grid <- grid.arrange(grobs = graphs, nrow = 1, ncol = 1,
                         top = textGrob({regressor_label},
                                        gp = gpar(fontsize = 20, font = 2)))
    ggsave(grid, file = glue("Figure {figure_no}.jpg"), 
           height = 10, width = 50, 
           units = "cm", dpi = 300)
  }
  
}


regressors<-list(c("elev", "Elevation", "A13a"), 
                 c("slope", "Slope", "A13b"),
                 c("icult_land_maj", "Cultivated Land", "A13c"),
                 c("total_road_1973", 'Road Density', "A13d"),
                 c("pop1972_sup_ha",  "Population Density", "A13e"),
                 c("cotton_intinput_irrigated", "Attainable Cotton Yield", "A13f"),
                 c("sugarcane_intinput_irrigated", "Attainable Sugarcane Yield", "A13g"),
                 c("mEE_DR_13_1980_pcSupM_adj", "Pct. Land Reformed", "A14a"),
                 c("fgt0", "Poverty Headcount Ratio (2009)", "A14b"),
                 c("fgt1", "Poverty Gap Index (2009)", "A14c"),
                 c("fgt2", "Poverty Severity (2009)", "A14d"),
                 c("pobreza13", "Poverty Headcount Ratio (2013)", "A14e"),
                 c("BD_educacion_3_2_matric_1ria_07", "Primary School Enrollment", "A14f"),
                 c("BD_educacion_3_3_matric_2ria_07", "Secondary School Enrollment", "A14g"),
                 c("tasa_desnutric_07", "Malnutrition Rate", "A14h"))


shortcut = glue("./Paper/figures")
setwd(shortcut)


create_graphs_per_specifications(regressors, mmdata)

  

