#This script produces all the jpegs for Figure A15.
rm(list = ls(all.names = TRUE))

#Step 1. Loading libraries
install.packages("ggplot2")
install.packages("glue")
install.packages("reshape2")
install.packages("lemon")


library("ggplot2")
library("glue")
library("reshape2")
library('lemon')

#Step 2. Setting directory
#Mac or Windows
setwd("/Users/bgpopescu/Dropbox/Education Project/")
setwd("C:/Users/bogdanp/Dropbox/Education project/")
setwd("C:/Users/Popescu/Dropbox/Education project/")


#Step 3. In case it does not exist already, manually create a folder called "figures" in the Paper folder
#so that you can save the output from this script.

#Step 4. Reading Data
data<-read.csv(file="./Data/data_final.csv", header=TRUE, sep=",")

#Step 5. Selecting the data for the area of interest
data_final<-subset(data, agrozone==3)

#Step 6. Creating distances for RD analysis
data_final$dist1 <- as.numeric( with (data_final,ifelse(data_final$treat==1, 1, -1)))
data_final$dist2 <-data_final$dist1*data_final$core13_dist

#Step 7. Creating a sequence with the distances of interest
sequence = seq(from = 10, to = 85, by = 1)
no_obs_treat = rep(NA, length(sequence))
no_obs_ctrl = rep(NA, length(sequence))


for (i in 1 : length(sequence)){
  no_obs_treat[i] <- nrow(data_final[which(data_final$dist2 > -sequence[i] & 
            data_final$dist2 < sequence[i] & data_final$treat==1),])

  no_obs_ctrl[i] <- nrow(data_final[which(data_final$dist2 > -sequence[i] & 
                 data_final$dist2 < sequence[i] & data_final$treat==0),])}


df <- data.frame(sequence = sequence, 
                 no_obs_treat = no_obs_treat,
                 no_obs_ctrl = no_obs_ctrl)

df2 <- melt(df, id.vars='sequence')
rm(df)
df2$label[df2$variable=='no_obs_ctrl']<-'Control'
df2$label[df2$variable=='no_obs_treat']<-'Treatment'

df_general<-subset(df2, variable=='no_obs_treat' | 
                     variable=='no_obs_ctrl')
rm(df2)


p<-ggplot(df_general, aes(x=sequence, y=value, fill= label)) +
  geom_bar(stat='identity', position='dodge', color=NA)+
  scale_fill_manual("", values=c("Control"="Black", "Treatment"="Gray50"),
                    guide='legend')+
  theme_bw() +
  scale_x_continuous(name = "Bandwidth (km)", limits = c(10, 85)) +
  scale_y_continuous(name = "No. of Observations") +
  ggtitle("No. of Observations with Distance") +
  theme(plot.title = element_text(hjust = 0.5, size=15),
        axis.text=element_text(size=12),
        axis.title.x = element_text(size=15),
        axis.title.y = element_text(size=15))+
  theme(legend.position=c(0.85,0.85),
        legend.box.background = element_rect(fill='white'),
        legend.background = element_blank(),
        legend.text=element_text(size=10))
  
p2<-reposition_legend(p, 'top left')

shortcut = glue("./Paper/figures")
setwd(shortcut)

ggsave(p2, 
       file="Figure A15.jpg", 
       height=10, width=20, 
       units = "cm", dpi=300)

